@@ -13,6 +13,7 @@ let with_temp_file sexp_of_t ~contents ~f =
   in
   Sys.remove fname;
   Printf.printf !"%{sexp:[ `Ok of t | `Error of exn ]}" result
+;;
 
 let%expect_test "file ending with an atom" =
   with_temp_file [%sexp_of: int] ~contents:"5" ~f:(fun fname ->
@@ -20,13 +21,19 @@ let%expect_test "file ending with an atom" =
   [%expect {|
      (Ok 5)
   |}]
+;;
 
 let%expect_test "file ending with an atom" =
   with_temp_file [%sexp_of: Sexplib.Sexp.t list] ~contents:"5" ~f:(fun fname ->
     let ic = open_in fname in
-    (match Sexplib.Sexp.input_sexps ic with
-     | x -> close_in ic; x
-     | exception e -> close_in ic; raise e));
+    match Sexplib.Sexp.input_sexps ic with
+    | x ->
+      close_in ic;
+      x
+    | exception e ->
+      close_in ic;
+      raise e);
   [%expect {|
      (Ok (5))
   |}]
+;;
