@@ -5,14 +5,15 @@
     This is already done by [Core], so any application that uses Core need not worry
     about this module at all. *)
 open Sexplib.Sexp
+
 open Sexplib.Conv
 
 let () =
-  Exn_converter.add ~finalise:false [%extension_constructor Unix.Unix_error]
-    (function
-      | Unix.Unix_error (err, loc, arg) ->
-        let err_str = Unix.error_message err in
-        List [Atom "Unix.Unix_error"; Atom err_str; Atom loc; Atom arg]
-      | _ -> assert false)
+  Exn_converter.add ~finalise:false [%extension_constructor Unix.Unix_error] (function
+    | Unix.Unix_error (err, loc, arg) ->
+      let err_str = Unix.error_message err in
+      List [ Atom "Unix.Unix_error"; Atom err_str; Atom loc; Atom arg ]
+    | _ -> assert false)
+;;
 
 let linkme = ()
